@@ -1,6 +1,6 @@
 #' Collection of custom tidiers
 #'
-#' \Sexpr[results=rd, stage=render]{lifecycle::badge("experimental")}
+#' \lifecycle{experimental}
 #' Collection of tidiers that can be passed to `tbl_regression()`
 #' and `tbl_uvregression()` to obtain modified results. See examples below.
 #'
@@ -18,11 +18,18 @@
 #' The tidier uses the output from `parameters::bootstrap_parameters(test = "p")`, and
 #' merely takes the result and puts it in `broom::tidy()` format.
 #'
+#' - `pool_and_tidy_mice()` tidier to report models resulting from multiply imputed data
+#' using the mice package. Pass the mice model object *before* the model results
+#' have been pooled. See example.
+#'
 #' Ensure your model type is compatible with the methods/functions used to estimate
 #' the model parameters before attempting to use the tidier with `tbl_regression()`
 #' @inheritParams broom::tidy.glm
-#' @inheritParams add_global_p.tbl_regression
+#' @inheritParams add_global_p
+#' @param pool.args named list of arguments passed to `mice::pool()` in
+#' `pool_and_tidy_mice()`. Default is `NULL`
 #' @param ... arguments passed to method;
+#' - `pool_and_tidy_mice()`: `mice::tidy(x, ...)`
 #' - `tidy_standardize()`: `effectsize::standardize_parameters(x, ...)`
 #' - `tidy_bootstrap()`: `parameters::bootstrap_parameters(x, ...)`
 #'
@@ -50,8 +57,11 @@
 #'
 #'
 #' # Example 3 ----------------------------------
-#' tidy_bootstrap_ex3 <-
-#'   tbl_regression(mod, tidy_fun = tidy_bootstrap)
+#' # Multiple Imputation using the mice package
+#' pool_and_tidy_mice_ex3 <-
+#'   suppressWarnings(mice::mice(trial, m = 2)) %>%
+#'   with(lm(age ~ marker + grade)) %>%
+#'   tbl_regression() # mice method called that uses `pool_and_tidy_mice()` as tidier
 #'
 #' @section Example Output:
 #' \if{html}{Example 1}
@@ -64,19 +74,19 @@
 #'
 #' \if{html}{Example 3}
 #'
-#' \if{html}{\figure{tidy_bootstrap_ex3.png}{options: width=47\%}}
+#' \if{html}{\figure{pool_and_tidy_mice_ex3.png}{options: width=47\%}}
 
 tidy_standardize <- function(x, exponentiate = FALSE,
                              conf.level = 0.95,
                              conf.int = TRUE,
-                             quiet = FALSE, ...) {
-  assert_package("effectsize", "tidy_standardize")
+                             ..., quiet = FALSE) {
+  assert_package("effectsize", "tidy_standardize()")
   dots <- list(...)
 
   # calculating standardize coefs
   std_coef_expr <- expr(effectsize::standardize_parameters(model = x, ci = !!conf.level, !!!dots))
   if (quiet == FALSE)
-    inform(glue("Estimating standardized coefs with\n  `{deparse(std_coef_expr)}`"))
+    inform(glue("tidy_standardize(): Estimating standardized coefs with\n  `{deparse(std_coef_expr, width.cutoff = 500L)}`"))
   std_coef <-
     expr(effectsize::standardize_parameters(model = !!x, ci = !!conf.level, !!!dots)) %>%
     eval()
@@ -103,13 +113,13 @@ tidy_standardize <- function(x, exponentiate = FALSE,
 tidy_bootstrap <- function(x, exponentiate = FALSE,
                            conf.level = 0.95,
                            conf.int = TRUE, ..., quiet = FALSE) {
-  assert_package("parameters", "bootstrap_parameters")
+  assert_package("parameters", "tidy_bootstrap()", version = "0.6.0")
   dots <- list(...)
 
   # calculating bootstrapped coefs
   boot_coef_expr <- expr(parameters::bootstrap_parameters(model = x, ci = !!conf.level, test = "p", !!!dots))
   if (quiet == FALSE)
-    inform(glue("Estimating bootstrapped coefs with\n  `{deparse(boot_coef_expr)}`"))
+    inform(glue("tidy_bootstrap(): Estimating bootstrapped coefs with\n  `{deparse(boot_coef_expr, width.cutoff = 500L)}`"))
   boot_coef <-
     expr(parameters::bootstrap_parameters(model = !!x, ci = !!conf.level, test = "p", !!!dots)) %>%
     eval()
@@ -130,3 +140,20 @@ tidy_bootstrap <- function(x, exponentiate = FALSE,
 
   tidy
 }
+
+#' @rdname custom_tidiers
+#' @export
+pool_and_tidy_mice <- function(x, pool.args = NULL, ..., quiet = FALSE) {
+  assert_package("mice", "pool_and_tidy_mice()", version = "3.10.0")
+  if(!inherits(x, "mira")) stop("Object `x=` must be of class 'mira'.", call. = FALSE)
+
+  dots <- list(...)
+
+  # printing code that will run
+  mice_expr <- expr(mice::pool(x, !!!pool.args) %>% mice::tidy(!!!dots))
+  if (quiet == FALSE)
+    inform(glue("pool_and_tidy_mice(): Tidying mice model with\n  `{deparse(mice_expr, width.cutoff = 500L)}`"))
+
+  # evaluating tidy expression
+  expr(mice::pool(!!x, !!!pool.args) %>% mice::tidy(!!!dots)) %>% eval()
+}
