@@ -20,7 +20,7 @@ trial %>%
   modify_header(stat_by = md("**{level}**<br>N =  {n} ({style_percent(p)}%)")) %>%
   add_n() %>%
   bold_labels() %>%
-  modify_spanning_header(starts_with("stat_") ~ "**Chemotherapy Treatment**")
+  modify_spanning_header(all_stat_cols() ~ "**Chemotherapy Treatment**")
 
 ## -----------------------------------------------------------------------------
 trial %>%
@@ -60,6 +60,27 @@ trial %>%
     label = list(age ~ "Patient Age", grade ~ "Tumor Grade")
   )  
 
+## -----------------------------------------------------------------------------
+# imagine that each patient recieved Drug A and Drug B (adding ID showing their paired measurements)
+trial_paired <-
+  trial %>%
+  select(trt, marker) %>%
+  group_by(trt) %>%
+  mutate(id = row_number()) %>%
+  ungroup()
+
+# you must first delete incomplete pairs from the data, then you can build the table
+trial_paired %>%
+  # delete missing marker values
+  filter(!is.na(marker)) %>%
+  # keep IDs with both measurements
+  group_by(id) %>%
+  filter(n() == 2) %>%
+  ungroup() %>%
+  # summarize data
+  tbl_summary(by = trt, include = -id) %>%
+  add_p(test = marker ~ "paired.t.test", group = id)
+
 ## -----------------------------------------------------------------------------
 # table summarizing data with no p-values
 t0 <- trial %>%
@@ -75,7 +96,7 @@ t1 <- trial %>%
   add_p() %>%
   modify_header(p.value ~ md("**I vs. II**")) %>%
   # hide summary stat columns
-  modify_table_header(starts_with("stat_"), hide = TRUE)
+  modify_table_header(all_stat_cols(), hide = TRUE)
 
 # table comparing grade I and II
 t2 <- trial %>%
@@ -85,18 +106,16 @@ t2 <- trial %>%
   add_p()  %>%
   modify_header(p.value ~ md("**I vs. III**")) %>%
   # hide summary stat columns
-  modify_table_header(starts_with("stat_"), hide = TRUE)
+  modify_table_header(all_stat_cols(), hide = TRUE)
 
 # merging the 3 tables together, and adding additional gt formatting
 tbl_merge(list(t0, t1, t2)) %>%
   modify_spanning_header(
     list(
-      starts_with("stat_") ~ "**Tumor Grade**",
-      starts_with("p.value") ~ "**p-value**"
+      all_stat_cols() ~ "**Tumor Grade**",
+      starts_with("p.value") ~ "**p-values**"
     )
-  ) %>%
-  # remove default spanning headers
-  modify_spanning_header(everything() ~ NA_character_)
+  )
 
 ## -----------------------------------------------------------------------------
 # define function for lower and upper bounds of the mean CI
