@@ -1,15 +1,19 @@
 context("test-continuous_digits_guess")
 testthat::skip_on_cran()
 
+continuous_digits_guess(
+  data = mtcars,
+  variable = "drat",
+  summary_type = "continuous"
+)
+
 test_that("guess digits: mtcars$drat", {
   expect_equal(
     continuous_digits_guess(
       data = mtcars,
       variable = "drat",
-      summary_type = "continuous",
-      class = "numeric",
-      digits = NULL
-    )[[1]],
+      summary_type = "continuous"
+    ),
     2
   )
 })
@@ -19,9 +23,7 @@ test_that("guess digits: mtcars$vs", {
     is.na(continuous_digits_guess(
       data = mtcars,
       variable = "vs",
-      summary_type = "dichotomous",
-      class = "numeric",
-      digits = NULL
+      summary_type = "dichotomous"
     ))
   )
 })
