@@ -65,13 +65,13 @@ test_that("vetted_models lmer()", {
     tbl_lmer_lin$table_body %>%
       filter(row_type == "label") %>%
       pull(label),
-    c("Age, yrs", "trt", "Grade")
+    c("Age", "trt", "Grade")
   )
   expect_equivalent(
     tbl_lmer_int$table_body %>%
       filter(row_type == "label") %>%
       pull(label),
-    c("Age, yrs", "trt", "Grade", "trt * Grade")
+    c("Age", "trt", "Grade", "trt * Grade")
   )
   # 2.  If applicable, runs as expected with logit and log link (NOT APPLICABLE)
   # 3.  Interaction terms are correctly printed in output table
